pub fn panic_hook()Expand description
Install a panic hook that sends panic details to Ray.
The default panic hook is still called after Ray receives the panic payloads.
pub fn panic_hook()Install a panic hook that sends panic details to Ray.
The default panic hook is still called after Ray receives the panic payloads.