RayBatch

Type Alias RayBatch 

pub type RayBatch = RayHandle<Buffered>;
Buffers multiple payloads and sends them in a single request with commit. Each payload becomes its own Ray entry; use chaining on a Ray handle to update a single entry. commit is best-effort and ignores transport errors; use try_commit to surface errors.

use ray::{Client, Origin, Ray, RayConfig};

let config = RayConfig {
    enabled: false,
    ..Default::default()
};
let ray = Ray::new(Client::new(config), Origin::default());

ray.batch()
    .log(&"batched")
    .green()
    .label("batch")
    .commit();

Aliased Type

pub struct RayBatch { /* private fields */ }